agenttools
==========

.. automodule:: abjad.tools.agenttools

.. only:: html

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.agenttools.InspectionAgent.InspectionAgent
      ~abjad.tools.agenttools.IterationAgent.IterationAgent
      ~abjad.tools.agenttools.MutationAgent.MutationAgent
      ~abjad.tools.agenttools.PersistenceAgent.PersistenceAgent
